@@ -120,7 +120,7 @@ class ObjectReader:
         elif isinstance(obj, list) or isinstance(obj, tuple) or isinstance(obj, set):
             index = IntegerConverter.to_nullable_integer(name)
             if index is not None and 0 <= index < len(obj):
-                return obj[index]
+                return list(obj)[index]
             return None
         else:
             return PropertyReflector.get_property(obj, name)
@@ -167,7 +167,7 @@ class ObjectReader:
         if isinstance(obj, dict):
             for (key, value) in obj.items():
                 map[key] = value
-        elif isinstance(obj, list) or isinstance(obj, tuple) or isinstance(obj, set):
+        elif isinstance(obj, (list, set, tuple)):
             for index in range(len(obj)):
                 map[str(index)] = obj[index]
         else:
